/* GStreamer
 * Copyright (C) 2012 GStreamer developers
 *
 * net.h: single include header for gst-net library
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef __GST_NET__H__
#define __GST_NET__H__

#include <gst/net/net-prelude.h>

#include <gst/net/gstnet.h>
#include <gst/net/gstnetaddressmeta.h>
#include <gst/net/gstnetcontrolmessagemeta.h>
#include <gst/net/gstnetclientclock.h>
#include <gst/net/gstnettimepacket.h>
#include <gst/net/gstnettimeprovider.h>
#include <gst/net/gstptpclock.h>

#endif /* __GST_NET__H__ */
